@@ -1,16 +1,14 @@
 #!/bin/sh
 set -eu
 
-export HOME="$(pwd)/debian/HOME"
-# Put these back to their defaults if we are not running with a clean
-# environment, so that they are based on the temporary $HOME above.
-unset XDG_CACHE_HOME
-unset XDG_CONFIG_DIRS
-unset XDG_CONFIG_HOME
-unset XDG_DATA_HOME
-unset XDG_DATA_DIRS
-# dconf assumes this directory exists and is writable
-export XDG_RUNTIME_DIR="$(pwd)/debian/XDG_RUNTIME_DIR"
+# Some build/test infrastructure provides internet access via a proxy.
+# libostree doesn't always support no_proxy (and in any case
+# reproducible-builds.org doesn't set it), so tests will try to use the
+# proxy for localhost, and fail to reach the test server.
+unset ftp_proxy
+unset http_proxy
+unset https_proxy
+unset no_proxy
 
 adverb=
 
